import { demoFunc } from './dees-simple-appdash.demo.js';
import {
  customElement,
  html,
  DeesElement,
  property,
  type TemplateResult,
  cssManager,
  css,
  unsafeCSS,
  type CSSResult,
  state,
} from '@design.estate/dees-element';

declare global {
  interface HTMLElementTagNameMap {
    'dees-simple-appdash': DeesSimpleAppDash;
  }
}

@customElement('dees-simple-appdash')
export class DeesSimpleAppDash extends DeesElement {
  // STATIC
  public static demo = demoFunc;
  // INSTANCE

  @property()
  public name = 'Dees Simple Login';

  public static styles = [
    cssManager.defaultStyles,
    css`
      :host {
        color: ${cssManager.bdTheme('#333', '#fff')};
        user-select: none;
      }
      .appbar {
        position: fixed;
        top: 0;
        height: 40px;
        width: 100%;
        background: ${cssManager.bdTheme('#eeeeeb', '#000')};
        border-bottom: 1px solid ${cssManager.bdTheme('#ccc', '#333')};
        font-size: 14px;
        line-height: 40px;
        font-family: 'Roboto', 'Inter', sans-serif;
        padding: 0px 16px;
        z-index: 2;
        box-shadow: 0px 0px 4px 0px rgba(0, 0, 0, 0.2);
        display: grid;
        grid-template-columns: 1fr auto;
      }

      .appActions {
        display: flex;
      }

      .appcontent {
        z-index: 1;
        position: fixed;
        top: 40px;
        height: calc(100vh - 40px);
        bottom: 0px;
        width: 100%;
        overflow: auto;
        background: ${cssManager.bdTheme('#eeeeeb', '#000')};
      }
    `,
  ];

  public render(): TemplateResult {
    return html`
      <div class="appbar">
        <div class="appName">${this.name}</div>
        <div class="appActions">
          <div class="action">
            Logout
          </div>
        </div>
      </div>
      <div class="appcontent">
        <slot></slot>
      </div>
    `;
  }

  public async firstUpdated(_changedProperties): Promise<void> {
    const domtools = await this.domtoolsPromise;
    super.firstUpdated(_changedProperties);
  }
}
